@@ -27,8 +27,8 @@
 #
 # Standard library
 # ----------------
-# None.
-#
+import sys
+
 # Third-party imports
 # -------------------
 # None.
@@ -36,14 +36,17 @@
 # Local application imports
 # -------------------------
 # None. Delay the import below until after print runs, since the import takes a while to complete.
-#
-#
+
+
 # Main
 # ====
-# Run both servers.
-if __name__ == "__main__":
+def main():
     # This file takes a long time to load and run. Print a status message as it starts.
     print("Loading...")
     from .server import run_servers
 
-    run_servers()
+    sys.exit(run_servers())
+
+
+if __name__ == "__main__":
+    main()
